@@ -1,11 +1,12 @@
 use strict;
 use warnings;
 package Time::C;
-$Time::C::VERSION = '0.006';
+$Time::C::VERSION = '0.007';
 # ABSTRACT: Convenient time manipulation.
 
 use overload (
     '""' => sub { shift->string },
+    bool => sub { 1 },
     fallback => 1,
 );
 
@@ -23,7 +24,14 @@ method new ($c: $year = undef, $month = 1, $day = 1, $hour = 0, $minute = 0, $se
 
     my $tm = Time::Moment->new(year => $year, month => $month, day => $day, hour => $hour, minute => $minute, second => $second, offset => 0);
 
-    $c->gmtime($tm->epoch)->tz($tz);
+    if ($tz ne 'UTC' and $tz ne 'GMT') {
+        my $offset = _get_offset($tm->epoch, $tz);
+        $tm = $tm->with_offset_same_local($offset);
+        $offset = _get_offset($tm->epoch, $tz);
+        $tm = $tm->with_offset_same_local($offset);
+    }
+
+    $c->localtime($tm->epoch, $tz);
 }
 
 
@@ -49,16 +57,8 @@ method from_string ($c: $str, $format = undef, $expected_tz = 'UTC') {
     bless {epoch => $p[0], tz => $p[1]}, $c;
 }
 
-fun constrain ($val, $min, $max) {
-    return not ($val > $max or $val < $min);
-}
-
 fun _verify_tz ($tz) {
-    unless ($tz =~ /^([+-]?\d+):(\d+)$/ and
-      constrain($1, -12, 14) and constrain($2, 0, 60)) {
-        croak sprintf "Unknown timezone: %s", $tz
-          unless eval { Time::Zone::Olson->new({timezone => $tz}); 1; };
-    }
+    _get_offset(time, $tz);
 }
 
 my %tz_offset = (
@@ -154,6 +154,24 @@ method tz ($t: $new_tz = undef) :lvalue {
     sentinel value => $t->{tz}, set => $setter;
 }
 
+fun _get_offset ($epoch, $tz) {
+    my $offset = eval { Time::Zone::Olson->new({timezone => $tz})
+      ->local_offset($epoch); };
+
+    if (not defined $offset) {
+        if ($tz =~ /^([+-])(\d+):(\d+)$/) {
+            my ($sign, $hour, $min) = ($1, $2, $3);
+            $offset = 60 * $hour + $min;
+            $offset = -$offset if $sign eq '-';
+        }
+    }
+
+    croak sprintf "Unknown timezone %s.", $tz
+      if not defined $offset;
+
+    return $offset;
+}
+
 
 method offset ($t: $new_offset = undef) :lvalue {
     my $setter = sub {
@@ -165,19 +183,7 @@ method offset ($t: $new_offset = undef) :lvalue {
 
     return $setter->($new_offset) if defined $new_offset;
 
-    my $offset = eval { Time::Zone::Olson->new({timezone => $t->{tz}})
-      ->local_offset($t->{epoch}); };
-
-    if (not defined $offset) {
-        if ($t->{tz} =~ /^([+-])(\d+):(\d+)$/) {
-            my ($sign, $hour, $min) = ($1, $2, $3);
-            $offset = 60 * $hour + $min;
-            $offset = -$offset if $sign eq '-';
-        }
-    }
-
-    croak sprintf "Unknown timezone %s.", $t->{tz}
-      if not defined $offset;
+    my $offset = _get_offset($t->{epoch}, $t->{tz});
 
     sentinel value => $offset, set => $setter;
 }
@@ -470,7 +476,7 @@ Time::C - Convenient time manipulation.
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -639,7 +645,7 @@ Note that an assignment expression will return the I<computed> value rather than
 
   $t = $t->epoch($new_epoch);
 
-Returns or sets the epoch according to the specified timezone.
+Returns or sets the epoch, i.e. the number of seconds since C<1970-01-01T00:00:00Z>.
 
 If the form C<< $t->epoch($new_epoch) >> is used, it likewise changes the epoch but returns the entire object.
 
